Attributes

Struct Attributes 

pub struct Attributes { /* private fields */ }
Collection of attributes.

Implementations

Source

impl Attributes

pub const fn new() -> Self

Create a new empty attribute collection.

pub const fn from_vec(attributes: Vec<Attribute>) -> Self

Create from a vector of attributes.

pub fn add(&mut self, attribute: Attribute) -> Result<()>

Add an attribute.

Errors

Returns error if an attribute with the same name already exists.

pub fn set(&mut self, attribute: Attribute)

Add or replace an attribute.

pub fn get(&self, name: &str) -> Option<&Attribute>

Get an attribute by name.

pub fn get_mut(&mut self, name: &str) -> Option<&mut Attribute>

Get a mutable reference to an attribute by name.

pub fn get_value(&self, name: &str) -> Option<&AttributeValue>

Get an attribute value by name.

pub fn contains(&self, name: &str) -> bool

Check if an attribute exists.

pub fn len(&self) -> usize

Get the number of attributes.

pub fn is_empty(&self) -> bool

Check if empty.

pub fn iter(&self) -> impl Iterator<Item = &Attribute>

Get an iterator over attributes.

pub fn names(&self) -> Vec<&str>

Get names of all attributes.

pub fn remove(&mut self, name: &str) -> Option<Attribute>

Remove an attribute by name.