Variable

Struct Variable 

pub struct Variable { /* private fields */ }
A variable in a NetCDF file.

Implementations

Source

impl Variable

pub fn new( name: impl Into<String>, data_type: DataType, dimension_names: Vec<String>, ) -> Result<Self>

Create a new variable.

Arguments
  • name - Name of the variable
  • data_type - Data type
  • dimension_names - Names of dimensions (in order)
Errors

Returns error if the name is empty.

pub fn new_coordinate( name: impl Into<String>, data_type: DataType, ) -> Result<Self>

Create a coordinate variable.

A coordinate variable has the same name as its dimension.

Arguments
  • name - Name of the variable and dimension
  • data_type - Data type
Errors

Returns error if the name is empty.

pub fn name(&self) -> &str

Get the variable name.

pub const fn data_type(&self) -> DataType

Get the data type.

pub fn dimension_names(&self) -> &[String]

Get the dimension names.

pub fn ndims(&self) -> usize

Get the number of dimensions.

pub fn is_scalar(&self) -> bool

Check if this is a scalar variable (no dimensions).

pub const fn is_coordinate(&self) -> bool

Check if this is a coordinate variable.

pub fn set_coordinate(&mut self, is_coordinate: bool)

Set whether this is a coordinate variable.

pub const fn attributes(&self) -> &Attributes

Get the attributes.

pub fn attributes_mut(&mut self) -> &mut Attributes

Get mutable access to attributes.

pub fn shape(&self, dimensions: &Dimensions) -> Result<Vec<usize>>

Get the shape based on dimensions.

Errors

Returns error if any dimension is not found.

pub fn size(&self, dimensions: &Dimensions) -> Result<usize>

Get the total size based on dimensions.

Errors

Returns error if any dimension is not found or if size overflows.

pub fn size_bytes(&self, dimensions: &Dimensions) -> Result<usize>

Get the size in bytes based on dimensions.

Errors

Returns error if any dimension is not found or if size overflows.

pub fn is_netcdf3_compatible(&self) -> bool

Check if compatible with NetCDF-3.